import requests
from flask import Flask

from skywalking_flask import SkywalkingFlask

app = Flask(__name__)
SkywalkingFlask(app, service='My Service 1', collector='192.168.3.202:11800')


@app.route('/')
def hello_world():
    r = requests.get("http://127.0.0.1:8081/hello")
    return r.text


if __name__ == '__main__':
    app.run(port=8080, host='127.0.0.1', debug=True)



from flask import Flask
from skywalking_flask import SkywalkingFlask

app = Flask(__name__)

SkywalkingFlask(app, service='My Service 2', collector='192.168.3.202:11800')


@app.route('/hello')
def hello_world():
    return 'Hello, World!'


if __name__ == '__main__':
    app.run(port=8081, host='127.0.0.1', debug=True)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

install_requires = [
    "flask",
    "apache-skywalking==0.3.0",
    "requests",
]

setuptools.setup(
    name="skywalking-flask",
    version="0.0.7",
    author="Parker Zhu",
    author_email="806000178@qq.com",
    description="Skywalking Flask Support.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitee.com/parkerzhu/skywalking-flask",
    install_requires=install_requires,
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.5'
)